// FILENAME:	noPadKill.cs
//
// AUTHORS:  	William
//
// Description: Anti pad\spawn killing script.
// When a vehicle is shutdown on a pad its team is changed to neutral,
// After it is powered up again its team is set back.
// Also when a new player joins or a vehicle is respawned its team is set to neutral
// for 5 seconds.
//------------------------------------------------------------------------------

$noPadKills = false;

// this overrides the standard function in multiplayerStdLib.
function Zen::work(%trigger, %object, %healRate, %ammoRate, %reset, %shutdown)
{
   // %trigger has been activated
   // %object receives %healRate amount of healing
   // %object receives %ammoRate percent of ammo to each weapon
   // %reset is how many seconds must pass before trigger is recharged
   // %shutdown is a boolean -- whether or not trigger requires shutdown
      
   if(
      (
         isShutDown(%object) == true ||      // is vehicle shut down?
         %shutdown == false                  // does it even matter?
      ) &&
      (
         %trigger.wait == false ||     // is trigger ready?
         %trigger.wait == "" ||
         %trigger.special == %object   // is object special?   
      ) &&
      (
         %trigger.depleted == "" ||    // is pad not depleted
         %trigger.depleted == false
      )
   )   
   {
      if(%healRate > 0)
      {
         // do the healing bit
         healObject(%object, %healRate);
      }
      
      if(%ammoRate > 0)
      {   
         // and the reloading bit
         reloadObject(%object, %ammoRate);
      }

      // make this object special
      if(%object != %trigger.special)
      {
          %trigger.special = %object;
          %object.pad = %trigger; // cross-link it
          if ($noPadKills == true) // if no pad kills is true then set team to neutral
          {
              say(0,0,getHUDName(%object)@": PAD!");
              %trigger.specialTeam = getTeam(%object);
              setTeam(%object, *IDSTR_TEAM_NEUTRAL);
          }
      }
      if(
         %reset > 0 &&           // if we require a reset   
         %trigger.reset == ""    // and it's not already scheduled
      )
      {      

         // schedule the depletion time (one third of reset time)
         schedule("Zen::depleted(" @ %trigger @ ");", (%reset / 3));

         // schedule the recharge time and store it for later
         %trigger.reset = schedule("Zen::recharged(" @ %trigger @ ");", %reset);
        
         // trigger is no longer ready
         %trigger.wait = true;
      }
   }
   else
   {
      // check to see if player has shut down and started up again
   
      if(
         %object == %trigger.special &&   // if object is special
         %shutdown == true &&             // and is on a pad that requires shutdown
         isShutDown(%object) == false     // and is no longer shut down
      )
      {
         // object is no longer special
         %trigger.special.pad = "";
         %trigger.special = "";      
         if ($noPadKills == true) // change back to orginal team
         {
             setTeam(%object, %trigger.specialTeam);
             %trigger.specialTeam = "";
         }
      }
   }
}

function player::onAdd(%this)
{
   player::onAddLog(%this);
	
	if($server::TeamPlay == true)
	{
      say(%this,0, *IDMULT_TDM_WELCOME);	      
   }
	else
	{
      say(%this,0, *IDMULT_DM_WELCOME);
   }
   // tell player if pad killing ig enabled or disabled
   if ($noPadKills == true) {say(%this,0,"No pad\spawn killing is enabled.");}
   else {say(%this,0,"No pad\spawn killing is disabled.");}
}   

function vehicle::onAdd(%this)
{
   %player = playerManager::vehicleIdToPlayerNum(%this);
   if($server::TeamPlay != true)
   {
   	// see if it is a player
      if(%player == 0)  // that's the server
         return;
         
      // so it's a player
      
      // shouldn't have to do this, but oh well
      setTeam(%this, *IDSTR_TEAM_RED);
   }
   if($noPadKills == true)
   {
      // set the team to neutral, this applies to AIs and players
      %team = getTeam(%this);
      setTeam(%this, *IDSTR_TEAM_NEUTRAL);
      // schedule change back to orginal team
      schedule("setTeam("@%this@", \""@%team@"\");",5);
   }
}

// this function enables or disables no pad\spawn killing in game
function setPadKills(%kills)
{
    $noPadKills = %kills;
    if ($noPadKills == true) {say(0,0,"No pad\spawn killing has been enabled.");}
    else {say(0,0,"No pad\spawn killing has been disabled.");}
}
